@@ -586,7 +586,8 @@ class LaggedAnalyser(object):
     
     
     def deseasonalise_variables(self,variable_list=None,dim='time',agg='dayofyear',smooth=1,coeffs=None):
-        """Computes a seasonal cycle for each variable in *LaggedAnalyser.variables* and subtracts it inplace, turning *LaggedAnalyser.variables* into deseasonalised anomalies. The seasonal cycle is computed via temporal aggregation of each variable over a given period - by default the calendar day of the year. This cycle can then be smoothed with an n-point rolling average.
+        
+         """Computes a seasonal cycle for each variable in *LaggedAnalyser.variables* and subtracts it inplace, turning *LaggedAnalyser.variables* into deseasonalised anomalies. The seasonal cycle is computed via temporal aggregation of each variable over a given period - by default the calendar day of the year. This cycle can then be smoothed with an n-point rolling average.
 
                 **Optional arguments**
 
@@ -606,7 +607,6 @@ class LaggedAnalyser(object):
                     A Dataset containing a precomputed seasonal cycle, which, if *LaggedAnalyser.variables* has coordinates (*dim*,[X,Y,...,Z]), has coords (*agg*,[X,Y,...,Z]), and has the same data variables as *LaggedAnalyser.variables*. If *coeffs* is provided, no seasonal cycle is fitted to *LaggedAnalyser.variables*, *coeffs* is used instead.
 
         """        
-
         if variable_list is None:
             variable_list=list(self.variables)
         for var in variable_list:
@@ -616,12 +616,12 @@ class LaggedAnalyser(object):
                 dsnlsr.fit_cycle(da,dim=dim,agg=agg)
             else:
                 dsnslr.cycle_coeffs=coeffs[var]
-
+                
             cycle=dsnlsr.evaluate_cycle(data=da[dim],smooth=smooth)
             self.variables[var]=da.copy(data=da.data-cycle.data)
             dsnlsr.data=None #Prevents excess memory storage
             self.deseasonalisers_[var]=dsnlsr
-        return   
+        return
     
     def get_seasonal_cycle_coeffs(self):
         """ Retrieve seasonal cycle coeffs computed with *LaggedAnalyser.deseasonalise_variables*, suitable for passing into *coeffs* in other *LaggedAnalyser.deseasonalise_variables* function calls as a precomputed cycle.
@@ -730,27 +730,27 @@ class PatternFilter(object):
         return
                   
     def apply_value_mask(self,truth_function,*args,mode='intersection'):
-        """ Apply a filter to *PatternFilter.mask_ds* based on a user-specified truth function which is applied to *PatternFilter.val_ds. 
-                **Examples**
-                    #Mask values beneath a threshold:
-                    def larger_than_thresh(ds,thresh):
-                        return ds>thresh
-                    patternfilter.apply_value_mask(is_positive,thresh)
+    """ Apply a filter to *PatternFilter.mask_ds* based on a user-specified truth function which is applied to *PatternFilter.val_ds. 
+            **Examples**
+                #Mask values beneath a threshold:
+                def larger_than_thresh(ds,thresh):
+                    return ds>thresh
+                patternfilter.apply_value_mask(is_positive,thresh)
+            
+                #Mask values where absolute value is less than a reference field:
+                def amp_greater_than_reference(ds,ref_ds):
+                    return np.abs(ds)>ref_ds
+                pattern_filter.apply_value_mask(amp_greater_than_reference,ref_ds)
+            
+            **Arguments**
 
-                    #Mask values where absolute value is less than a reference field:
-                    def amp_greater_than_reference(ds,ref_ds):
-                        return np.abs(ds)>ref_ds
-                    pattern_filter.apply_value_mask(amp_greater_than_reference,ref_ds)
-
-                **Arguments**
-
-                    *truth_function*
-                    A function with inputs (val_ds,*args) that returns a boolean dataset with the same coords and data variables as *PatternFilter.val_ds*.
-
-                **Optional arguments**
-                    *mode*
-                    A string, one of 'replace','intersection' or 'union', defining how the value filter should be used to update the *PatternFilter.mask_ds*.
-        """        
+                *truth_function*
+                A function with inputs (val_ds,*args) that returns a boolean dataset with the same coords and data variables as *PatternFilter.val_ds*.
+                
+            **Optional arguments**
+                *mode*
+                A string, one of 'replace','intersection' or 'union', defining how the value filter should be used to update the *PatternFilter.mask_ds*.
+            """        
         if self.val_ds is None:
             raise(ValueError('val_ds must be provided to apply value mask.'))
         value_mask=truth_function(self.val_ds,*args)
@@ -862,9 +862,6 @@ def _Dataset_to_dict(ds):
     return {v:d['data'] for v,d in ds.to_dict()['data_vars'].items()}
 
 class IndexGenerator(object):
-    
-    """ Computes dot-products between a Dataset of patterns and a Dataset of variables, reducing them to standardised scalar indices.
-    """
     def __init__(self):
         self._means=[]
         self._stds=[]
@@ -902,42 +899,7 @@ class IndexGenerator(object):
             weights=np.cos(np.deg2rad(ix[lat_dim]))
             return ix.weighted(weights).sum(dims)
             
-    def generate(self,pattern_ds,series_ds,dim='time',slices=None,ix_means=None,ix_stds=None,drop_blank=False,in_place=True,strict_metadata=False):
-        """Compute standardised indices from an xarray.Dataset of patterns and an xarray.Dataset of arbitrary dimension variables.
-        
-        **Arguments**
-        
-        *pattern_ds*
-        
-        An xarray.Dataset of patterns to project onto with arbitrary dimensions.
-        
-        series_ds*
-        
-        An xarray.Dataset of variables to project onto the patterns. Coordinates of *series_ds* once subsetted using *slices* must match the dimensions of *pattern_ds* + the extra coord *dim*.
-        **Optional arguments**
-        
-        *dim*:
-        A string specifying the remaining coord of the scalar indices. Defaults to 'time', which should be the choice for most use cases.
-        
-        *slices*
-        A dictionary or iterable of dictionaries, each specifying a subset of *pattern_ds* to take before computing an index, with one index returned for each dictionary and for each variable. Subsetting is based on the *xr.Dataset.sel* method: e.g. *slices*=[dict(lag=0,index_val=1)] will produce 1 set of indices based on pattern_ds.sel(lag=0,index_val=1). If *slices*=None, no subsets are computed.
-        
-        *ix_means*
-        If None, the mean of each index is calculated and subtracted, resulting in centred indices. Otherwise, *ix_means* should be a dictionary of index names and predefined mean values which are subtracted instead. Of most use for online computations, updating a precomputed index in a new dataset.
-        
-        *ix_stds*
-        If None, the standard deviation of each index is calculated and is divided by, resulting in standardised indices. Otherwise, *ix_stds* should be a dictionary of index names and predefined std values which are divided by instead. Of most use for online computations, updating a precomputed index in a new dataset.
-
-        *drop_blank*
-        A boolean. If True, drop indices where the corresponding pattern is entirely blank. If False, returns an all np.nan time series.
-        *in_place*
-        
-        *strict_metadata*
-        If False, indices will be merged into a common dataset regardless of metadata. If True, nonmatching metadata will raise a ValueError.
-        
-        **Returns
-        An xarray.Dataset of indices with a single coordinate (*dim*).
-        """
+    def generate(self,pattern_ds,series_ds,dim='time',ix_means=None,ix_stds=None,slices=None,drop_blank=False,in_place=True,strict_metadata=False):
         #Parse inputs
         
         if slices is None:
@@ -1024,9 +986,6 @@ class IndexGenerator(object):
         return index.rename({v:func(v,sl) for v in index.data_vars})
     
     def get_standardisation_params(self,as_dict=False):
-        
-        """ Retrieve index means and stds for computed indices, for use as future inputs into index_means or index_stds in *IndexGenerator.Generate*
-        """
         if as_dict:
             return self.means,self.stds
         else:
